=======
plugins
=======

API Reference for the ``Litestar.Plugins`` module

.. note:: Private methods and attributes are not included in the API reference.

Available API References
------------------------

.. toctree::
    :titlesonly:

    serialization
    init/plugin
    init/config/asyncio
    init/config/common
    init/config/engine
    init/config/sync
    init/config/types
